==> clevercherry-media-manager-1.0.7-881a84.zip: src/Views/partials/media-modal.blade.php <==
<div class="modal fade dev-modal" tabindex="-1" role="dialog" aria-labelledby="{{ $id }}Label" aria-hidden="true" id="{{ $id }}">
    <div class="modal-dialog modal-gallery modal-dialog-centered">
        <div class="modal-content">
            <div class="pb-5">
                     <div class="modal-header-lg">
                        <h3 class="modal-title-lg pl-header py-5 mb-0">{{ (isset($header)) ? $header : 'Media Manager' }}</h3>
                        <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                            <span aria-hidden="true">&times;</span>
                        </button>
                    </div>
             </div>
            <div class="modal-padding">
                <div class="row">
                    <div class="col-12">
                        <ul class="nav nav-tabs media-tabs" id="myTab" role="tablist">
                            @foreach($options AS $key => $value)
                            <li class="nav-item">
                                <a class="nav-link media-nav" id="{{ $key }}-tab" data-toggle="tab" href="#gallery{{ $value['ident'] }}" role="tab" aria-controls="home" aria-selected="true">{!! $key !!}</a>
                            </li>
                            @endforeach
                        </ul>
                    </div>
                </div>
                <div class="row mx-0">
                    <div class="col-12 h-100">
                        <div class="tab-content h-100" id="myTabContent">
                            @foreach($options AS $key => $value)
                            <div class="tab-pane fade h-100 media-tab-content" id="gallery{{ $value['ident'] }}" role="tabpanel" aria-labelledby="{{ $key }}-tab">
                                @include('media::partials.media-sortable')
                            </div>
                                @include('media::partials.cropper-js')
                            @endforeach
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>

==> clevercherry-media-manager-1.0-326246.zip: src/Views/partials/media-modal.blade.php <==
<div class="modal fade dev-modal" tabindex="-1" role="dialog" aria-labelledby="{{ $id }}Label" aria-hidden="true" id="{{ $id }}">
    <div class="modal-dialog modal-gallery modal-dialog-centered">
        <div class="modal-content">
            <div class="pb-5">
                     <div class="modal-header-lg">
                        <h3 class="modal-title-lg pl-header py-5 mb-0">{{ (isset($header)) ? $header : 'Media Manager' }}</h3>
                        <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                            <span aria-hidden="true">&times;</span>
                        </button>
                    </div>
             </div>
            <div class="modal-padding">
                <div class="row">
                    <div class="col-12">
                        <ul class="nav nav-tabs" id="myTab" role="tablist">
                            @foreach($options AS $key => $value)
                            <li class="nav-item">
                                <a class="nav-link media-nav" id="{{ $key }}-tab" data-toggle="tab" href="#gallery{{ $value['ident'] }}" role="tab" aria-controls="home" aria-selected="true">{!! $key !!}</a>
                            </li>
                            @endforeach
                        </ul>
                    </div>
                </div>
                <div class="row mx-0">
                    <div class="col-12 h-100">
                        <div class="tab-content h-100" id="myTabContent">
                            @foreach($options AS $key => $value)
                            <div class="tab-pane fade h-100" id="gallery{{ $value['ident'] }}" role="tabpanel" aria-labelledby="{{ $key }}-tab">
                                @include('media::partials.media-sortable')
                            </div>
                                @include('media::partials.cropper-js')
                            @endforeach
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>
